// Expand LEDs from the center in blue
#include <Adafruit_NeoPixel.h>

#ifdef __AVR__
 #include <avr/power.h>
#endif

#define PIN        D10  // Pin where the NeoPixels are connected
#define NUMPIXELS  50  // Number of LEDs in the strip

// Variables to define the total number of LEDs that light up on each side
#define STEPS_LEFT   24  // Number of LEDs that light up to the left in total
#define STEPS_RIGHT  24  // Number of LEDs that light up to the right in total

// Color variables
#define COLOR_BLUE   pixels.Color(0, 0, 255)
#define COLOR_GREEN  pixels.Color(0, 255, 0)
#define COLOR_RED    pixels.Color(255, 0, 0)
#define COLOR_GRAY   pixels.Color(50, 50, 50)
#define COLOR_OFF    pixels.Color(0, 0, 0)

Adafruit_NeoPixel pixels(NUMPIXELS, PIN, NEO_GRB + NEO_KHZ800);

void setup() {
  pixels.begin();
  pixels.clear();
  pixels.show();
}

void loop() {
  int center = NUMPIXELS / 2;
  pixels.clear();

  // Set all LEDs to a dim gray tone
  for (int i = 0; i < NUMPIXELS; i++) {
    pixels.setPixelColor(i, COLOR_GRAY);
  }

  // Turn on the three central LEDs in blue
  pixels.setPixelColor(center - 1, COLOR_BLUE);
  pixels.setPixelColor(center, COLOR_BLUE);
  pixels.setPixelColor(center + 1, COLOR_BLUE);
  pixels.show();
  delay(200);

  // Light up LEDs one by one outward until reaching the defined values
  for (int i = 0; i < max(STEPS_LEFT, STEPS_RIGHT); i++) {
    if (i < STEPS_LEFT && center - 2 - i >= 0) {
      pixels.setPixelColor(center - 2 - i, COLOR_GREEN); // Green to the left
    }
    if (i < STEPS_RIGHT && center + 2 + i < NUMPIXELS) {
      pixels.setPixelColor(center + 2 + i, COLOR_RED); // Red to the right
    }
    pixels.show();
    delay(200);
  }

  // Keep LEDs on for 5 seconds
  delay(5000);

  // Blink twice, alternating between dim gray and off
  for (int j = 0; j < 2; j++) {
    for (int i = 0; i < NUMPIXELS; i++) {
      pixels.setPixelColor(i, COLOR_GRAY);
    }
    pixels.show();
    delay(500);
    
    for (int i = 0; i < NUMPIXELS; i++) {
      pixels.setPixelColor(i, COLOR_OFF);
    }
    pixels.show();
    delay(500);
  }

  // Maintain dim gray instead of turning off completely
  for (int i = 0; i < NUMPIXELS; i++) {
    pixels.setPixelColor(i, COLOR_GRAY);
  }
  pixels.show();
  delay(2000);
}